@@ -29,7 +29,7 @@
 #'
 #' # Use in a user facing function
 #' fun <- function(i, d, l, chr, b) {
-#'     assert_scalar_int(i)
+#'     .assert_scalar_int(i)
 #'     TRUE
 #' }
 #' fun(i=1L)
@@ -38,7 +38,7 @@
 #'
 #' # Use in an internal function
 #' internal_fun <- function(a) {
-#'     assert_string(a, arg = deparse(substitute(a)), call = sys.call(-1L))
+#'     .assert_string(a, arg = deparse(substitute(a)), call = sys.call(-1L))
 #'     TRUE
 #' }
 #' external_fun <- function(b) {
@@ -49,13 +49,11 @@
 #' try(external_fun(b = letters))
 #'
 # -------------------------------------------------------------------------
-#' @name assertions
+#' @noRd
 NULL
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_integer <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_integer <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.integer(x))
@@ -63,14 +61,10 @@ assert_integer <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_int <- assert_integer
+.assert_int <- .assert_integer
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_double <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_double <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.double(x))
@@ -78,14 +72,10 @@ assert_double <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L))
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_dbl <- assert_double
+.assert_dbl <- .assert_double
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_numeric <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_numeric <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.numeric(x))
@@ -93,14 +83,10 @@ assert_numeric <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_num <- assert_numeric
+.assert_num <- .assert_numeric
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_logical <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_logical <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.logical(x))
@@ -108,14 +94,10 @@ assert_logical <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_lgl <- assert_logical
+.assert_lgl <- .assert_logical
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_character <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_character <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.character(x))
@@ -123,14 +105,10 @@ assert_character <- function(x, arg = deparse(substitute(x)), call = sys.call(-1
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_chr <- assert_character
+.assert_chr <- .assert_character
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_data_frame <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_data_frame <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.data.frame(x))
@@ -138,9 +116,7 @@ assert_data_frame <- function(x, arg = deparse(substitute(x)), call = sys.call(-
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_list <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_list <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.list(x))
@@ -148,168 +124,124 @@ assert_list <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_integer <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_scalar_integer <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
-    if (!(is.integer(x) && length(x) == 1))
+    if (!(is.integer(x) && length(x) == 1L))
         stopf("`%s` must be an integer vector of length 1.", arg, .call = call)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_int <- assert_scalar_integer
+.assert_scalar_int <- .assert_scalar_integer
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_integer_not_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_scalar_integer_not_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
-    if (!(is.integer(x) && length(x) == 1) || is.na(x))
+    if (!(is.integer(x) && length(x) == 1L) || is.na(x))
         stopf("`%s` must be an integer vector of length 1 and not NA.", arg, .call = call)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_int_not_na <- assert_scalar_integer_not_na
+.assert_scalar_int_not_na <- .assert_scalar_integer_not_na
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_double <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_scalar_double <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
-    if (!(is.double(x) && length(x) == 1))
+    if (!(is.double(x) && length(x) == 1L))
         stopf("`%s` must be a double vector of length 1.", arg, .call = call)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_dbl <- assert_scalar_double
+.assert_scalar_dbl <- .assert_scalar_double
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_double_not_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_scalar_double_not_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
-    if (!(is.double(x) && length(x) == 1) || is.na(x))
+    if (!(is.double(x) && length(x) == 1L) || is.na(x))
         stopf("`%s` must be a double vector of length 1 and not NA.", arg, .call = call)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_dbl_not_na <- assert_scalar_double_not_na
+.assert_scalar_dbl_not_na <- .assert_scalar_double_not_na
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_numeric <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_scalar_numeric <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
-    if (!(is.numeric(x) && length(x) == 1))
+    if (!(is.numeric(x) && length(x) == 1L))
         stopf("`%s` must be a numeric vector of length 1.", arg, .call = call)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_num <- assert_scalar_numeric
+.assert_scalar_num <- .assert_scalar_numeric
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_numeric_not_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_scalar_numeric_not_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
-    if (!(is.numeric(x) && length(x) == 1) || is.na(x))
+    if (!(is.numeric(x) && length(x) == 1L) || is.na(x))
         stopf("`%s` must be a numeric vector of length 1 and not NA.", arg, .call = call)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_num_not_na <- assert_scalar_numeric_not_na
+.assert_scalar_num_not_na <- .assert_scalar_numeric_not_na
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_logical <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_scalar_logical <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
-    if (!(is.logical(x) && length(x) == 1))
+    if (!(is.logical(x) && length(x) == 1L))
         stopf("`%s` must be a logical vector of length 1.", arg, .call = call)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_lgl <- assert_scalar_logical
+.assert_scalar_lgl <- .assert_scalar_logical
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_bool <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_bool <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
-    if (!(is.logical(x) && length(x) == 1) || is.na(x))
+    if (!(is.logical(x) && length(x) == 1L) || is.na(x))
         stopf("`%s` must be boolean (TRUE/FALSE).", arg, .call = call)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_boolean <- assert_bool
+.assert_boolean <- .assert_bool
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_character <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_scalar_character <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
-    if (!(is.character(x) && length(x) == 1))
+    if (!(is.character(x) && length(x) == 1L))
         stopf("`%s` must be a character vector of length 1.", arg, .call = call)
 
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_chr <- assert_scalar_character
+.assert_scalar_chr <- .assert_scalar_character
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_character_not_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_scalar_character_not_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
-    if (!(is.character(x) && length(x) == 1) || is.na(x))
+    if (!(is.character(x) && length(x) == 1L) || is.na(x))
         stopf("`%s` must be a character vector of length 1 and not NA.", arg, .call = call)
 
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_scalar_chr_not_na <- assert_scalar_character_not_na
+.assert_scalar_chr_not_na <- .assert_scalar_character_not_na
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_string <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
-    assert_scalar_chr(x = x, arg = arg, call = call)
+.assert_string <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+    .assert_scalar_chr(x = x, arg = arg, call = call)
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_non_negative_or_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_non_negative_or_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.numeric(x))
@@ -321,9 +253,7 @@ assert_non_negative_or_na <- function(x, arg = deparse(substitute(x)), call = sy
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_non_positive_or_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_non_positive_or_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.numeric(x))
@@ -335,9 +265,7 @@ assert_non_positive_or_na <- function(x, arg = deparse(substitute(x)), call = sy
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_non_negative <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_non_negative <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.numeric(x))
@@ -349,9 +277,7 @@ assert_non_negative <- function(x, arg = deparse(substitute(x)), call = sys.call
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_non_positive <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_non_positive <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.numeric(x))
@@ -363,9 +289,7 @@ assert_non_positive <- function(x, arg = deparse(substitute(x)), call = sys.call
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_positive <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_positive <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.numeric(x))
@@ -377,9 +301,7 @@ assert_positive <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_negative <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_negative <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.numeric(x))
@@ -391,9 +313,7 @@ assert_negative <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_positive_or_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_positive_or_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.numeric(x))
@@ -405,9 +325,7 @@ assert_positive_or_na <- function(x, arg = deparse(substitute(x)), call = sys.ca
 }
 
 # -------------------------------------------------------------------------
-#' @rdname assertions
-#' @export
-assert_negative_or_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
+.assert_negative_or_na <- function(x, arg = deparse(substitute(x)), call = sys.call(-1L)) {
     .assert_not_missing(x = x, arg = arg, call = call)
 
     if (!is.numeric(x))
@@ -447,7 +365,7 @@ assert_negative_or_na <- function(x, arg = deparse(substitute(x)), call = sys.ca
     if (length(x) == 0L)
         return(TRUE)
     min <- min(x)
-    if(is.na(min))
+    if (is.na(min))
         return(FALSE)
     if (min >= 0) TRUE else FALSE
 }
@@ -458,7 +376,7 @@ assert_negative_or_na <- function(x, arg = deparse(substitute(x)), call = sys.ca
     if (length(x) == 0L)
         return(TRUE)
     max <- max(x)
-    if(is.na(max))
+    if (is.na(max))
         return(FALSE)
     if (max <= 0) TRUE else FALSE
 }
@@ -508,4 +426,3 @@ assert_negative_or_na <- function(x, arg = deparse(substitute(x)), call = sys.ca
 }
 
 # -------------------------------------------------------------------------
-
